@@ -1,7 +1,8 @@
 import argparse
-import yaml
-import re
 import os
+import re
+
+import yaml
 
 
 def compile(env_line):
@@ -30,12 +31,8 @@ def compile_files(input_files):
     return content
 
 
-def main():
-    parser = argparse.ArgumentParser()
-    parser.add_argument("spec_file")
-
-    args = parser.parse_args()
-    with open(args.spec_file) as f:
+def run(spec_file):
+    with open(spec_file) as f:
         spec = yaml.load(f, Loader=yaml.FullLoader)
 
     for output_filename, input_files in spec.items():
@@ -44,5 +41,13 @@ def main():
             f.write(content)
 
 
+def main():
+    parser = argparse.ArgumentParser()
+    parser.add_argument("spec_file")
+
+    args = parser.parse_args()
+    run(args.spec_file)
+
+
 if __name__ == "__main__":
-    main()
\ No newline at end of file
+    main()
